@@ -20,6 +20,10 @@ INSTDIR="$(pwd)/inst"
 PATCHSCRIPTDIR="$(pwd)/patchscripts"
 export SRC SRCURL BUILDDIR PATCHDIR OUTDIR INSTDIR PATCHSCRIPTDIR
 
+# Must be kept in-sync with "../tcl/build.sh"
+TCLFOSSILDATE="../tcl/src/tcl${TCLVERS}.tar.gz.date"
+export TCLFOSSILDATE
+
 rm -rf 'build' 'out' 'inst'
 mkdir 'build' 'out' 'inst' || exit 1
 
@@ -34,14 +38,17 @@ export TCL_VERSION
 if [ ! -f "${SRC}" ]; then
 	mkdir 'src' >/dev/null 2>/dev/null
 
+	use_fossil='0'
 	if echo "${TCLVERS}" | grep '^cvs_' >/dev/null; then
-		CVSTAG=$(echo "${TCLVERS}" | sed 's/^cvs_//g')
-		if [ "${CVSTAG}" = "HEAD" ]; then
-			CVSTAG="trunk"
-		fi
-		export CVSTAG
+		use_fossil='1'
+	elif echo "${TCLVERS}" | grep '^fossil_' >/dev/null; then
+		use_fossil='1'
+	fi
 
+	if [ "${use_fossil}" = "1" ]; then
 		(       
+			FOSSILDATE="$(cat "${TCLFOSSILDATE}" 2>/dev/null)"
+
 			cd src || exit 1
 
 			workdir="tmp-$$${RANDOM}${RANDOM}${RANDOM}"
@@ -50,10 +57,10 @@ if [ ! -f "${SRC}" ]; then
 			mkdir "${workdir}" || exit 1
 			cd "${workdir}" || exit 1
 
-			wget -O "tmp-tk.tar.gz" "http://core.tcl.tk/tk/tarball/tk-${CVSTAG}.tar.gz?uuid=${CVSTAG}" || rm -f 'tmp-tk.tar.gz'
+			wget -O "tmp-tk.tar.gz" "http://core.tcl.tk/tk/tarball/tk-fossil.tar.gz?uuid=${FOSSILDATE}" || rm -f 'tmp-tk.tar.gz'
 			gzip -dc "tmp-tk.tar.gz" | tar -xf -
 
-			mv "tk-${CVSTAG}" "tk${TCLVERS}"
+			mv "tk-fossil" "tk${TCLVERS}"
                         
 			tar -cf - "tk${TCLVERS}" | gzip -c > "../../${SRC}"
 
@@ -168,6 +175,12 @@ fi
 
 		# Update to include resources, if found
 		if [ "${dir}" = "win" ]; then
+			echo ' *** Importing user-specified icon'
+			cp "${KITCREATOR_ICON}" rc/tk.ico
+
+			echo ' *** Importing user-specified resources'
+			cat "${KITCREATOR_RC}" | grep -v '^ *tclsh  *ICON' >> "./rc/tk_base.rc"
+
 			echo ' *** Creating tkbase.res.o to support Windows build'
 			echo "\"${RC:-windres}\" -o tkbase.res.o  --define STATIC_BUILD --include \"./../generic\" --include \"${TCLCONFIGDIR}/../generic\" --include \"${TCLCONFIGDIR}\" --include \"./rc\" \"./rc/tk_base.rc\""
 			"${RC:-windres}" -o tkbase.res.o  --define STATIC_BUILD --include "./../generic" --include "${TCLCONFIGDIR}/../generic" --include "${TCLCONFIGDIR}" --include "./rc" "./rc/tk_base.rc"
